import unittest
from myFitter import *

def relDev(a, b):
    return 0.0 if a == b == 0.0 else 2.0*(a-b)/(abs(a)+abs(b))

class MyModel(Model):
    def __init__(self):
        Model.__init__(self)

        self.addParameter('p1', generator=lambda: random.gauss(0.0,1.0))
        self.addParameter('p2', generator=lambda: random.gauss(0.0,1.0))

        self.addGaussianCSC('o1', 0.0, 1.0)
        self.addGaussianCSC('o2', 0.0, 1.0)
        self.addGaussianCSC('o3', 1.0, 1.0)

    def getDependentQuantities(self, p):
        q = Model.getDependentQuantities(self, p)

        q['o1'] = q['p1']
        q['o2'] = q['p2']
        q['o3'] = -q['p1']**2 - q['p2']**2
        q['p1p2'] = q['p1']*q['p2']

        return q

class MyProfiler1D(Profiler1D):
    def fit(self, xval=None, start=[], sample=True,
            nsamples=100, tries=5, log=None, **kwargs):
        self.fix(xval)
        return fit(self.model, **kwargs)

class MyProfiler2D(Profiler2D):
    def fit(self, xval=None, yval=None, start=[], sample=True,
            nsamples=100, tries=5, log=None, **kwargs):
        self.fix(xval, yval)
        return fit(self.model, **kwargs)

class ProfilerTest(unittest.TestCase):
    def setUp(self):
        random.seed(1234)

    def test_Profiler1D(self):
        model = MyModel()
        hist = Histogram1D(xbins=[-0.2,0.2])
        profiler = MyProfiler1D('p1', model=model)
        profiler.scan(hist)

    def test_Profiler2D(self):
        model = MyModel()
        hist = Histogram2D(xbins=[-0.2,0.2],
                           ybins=[-0.2,0.2])
        profiler = MyProfiler2D('p1', 'p2', model=model)
        profiler.scan(hist)



